📁 Context
├── 📁 01 Vault
│ ├── 📄 (Decision) Should We Share Operational and Conceptual Knowledge in the Same Vault.md
│ ├── 📄 (Prompt) Transcript Cleaner V1.md
│ ├── 📄 (Prompt) Transcript Summariser V0.1.md
│ ├── 📄 Academic Research.md
│ ├── 📄 Cognition OS.md
│ ├── 📄 Cognitive Engineering (Conception).md
│ ├── 📄 Cognitive Engineering.md
│ ├── 📄 Company.md
│ ├── 📄 Conventions.md
│ ├── 📄 Dashboard.md
│ ├── 📄 Decisions.md
│ ├── 📄 General Meeting (2025-07-24) {Cleaned}.md
│ ├── 📄 General Meeting (2025-07-24) {Summary}.md
│ ├── 📄 General Meeting (2025-07-24).md
│ ├── 📄 General Meeting (2025-07-27) {Cleaned}.md
│ ├── 📄 General Meeting (2025-07-27) {Summary}.md
│ ├── 📄 General Meeting (2025-07-27).md
│ ├── 📄 General Meeting (2025-07-28) {Cleaned}.md
│ ├── 📄 General Meeting (2025-07-28) {Summary}.md
│ ├── 📄 General Meeting (2025-07-28).md
│ ├── 📄 General Meetings.md
│ ├── 📄 History.md
│ ├── 📄 MEC Startup Competition Context.md
│ ├── 📄 MEC Startup Competition Rules & Handbook.md
│ ├── 📄 MEC Startup Competition.md
│ ├── 📄 MKD (Brainstorming).md
│ ├── 📄 MKD.md
│ ├── 📄 Markdown.md
│ ├── 📄 NUU Branding.md
│ ├── 📄 NUU Build In Public Thread (2025-07-29) {Cleaned}.md
│ ├── 📄 NUU Build In Public Thread (2025-07-29).md
│ ├── 📄 NUU Cognition Context Dump (2025-07-29).md
│ ├── 📄 NUU Cognition Context.md
│ ├── 📄 NUU Cognition Strategy.md
│ ├── 📄 NUU Cognition.md
│ ├── 📄 NUU Core (Export).md
│ ├── 📄 NUU Core Meeting (2025-07-24) {Cleaned}.md
│ ├── 📄 NUU Core Meeting (2025-07-24).md
│ ├── 📄 NUU Core.md
│ ├── 📄 NUU Design Document 1.0 (2025-07-30).md
│ ├── 📄 NUU Dictate.md
│ ├── 📄 NUU Echo.md
│ ├── 📄 NUU File to Markdown Service.md
│ ├── 📄 NUU Home.md
│ ├── 📄 NUU Infrastructure.md
│ ├── 📄 NUU Library.md
│ ├── 📄 NUU Reason.md
│ ├── 📄 NUU Suite.md
│ ├── 📄 NUU Surf (Archive).md
│ ├── 📄 NUU Surf Data Structure Meeting (2025-07-29) {Cleaned}.md
│ ├── 📄 NUU Surf Data Structure Meeting (2025-07-29).md
│ ├── 📄 NUU Surf Frontend Technical Progress Update (2025-07-30).md
│ ├── 📄 NUU Surf MVP Meeting (2025-07-29) {Cleaned}.md
│ ├── 📄 NUU Surf MVP Meeting (2025-07-29).md
│ ├── 📄 NUU Surf Technical Context.md
│ ├── 📄 NUU Surf.md
│ ├── 📄 NUU Technical Meeting (2025-07-28) {Cleaned}.md
│ ├── 📄 NUU Technical Meeting (2025-07-28).md
│ ├── 📄 NUU Transform.md
│ ├── 📄 Nathan Luo.md
│ ├── 📄 Nathan's Page.md
│ ├── 📄 Obsidian.md
│ ├── 📄 Prompt Library.md
│ ├── 📄 Team.md
│ ├── 📄 Technical Guides.md
│ ├── 📄 Temp.md
│ ├── 📄 Text Data Modelling.md
│ ├── 📄 Text Is All You Need.md
│ ├── 📄 Top of Mind.md
│ ├── 📄 Welcome.md
│ └── 📄 Yosh's Startup Template.md
├── 📁 02 Journal
│ ├── 📄 02 Journal.md
│ └── 📄 2025-07-27.md
├── 📁 03 Records
│ ├── 📄 03 Records.md
│ └── 📁 0302 Chats
│ ├── 📄 0302 Chats.md
│ └── 📄 o3-pro 2025-07-27 (Core Application Structure).md
├── 📁 04 Daily Notes
│ ├── 📄 2025-07-27.md
│ ├── 📄 2025-07-28.md
│ ├── 📄 2025-07-29.md
│ └── 📄 2025-07-30.md
├── 📁 04 Sources
│ └── 📄 04 Sources.md
├── 📁 05 Media
│ └── 📄 05 Media.md
├── 📁 06 Extras
│ ├── 📄 06 Extras.md
│ └── 📁 09 Templates
│ └── 📄 09 Templates.md
└── 📁 09 Exports
├── 📄 09 Exports.md
├── 📄 NUU Surf Techincal Context.pdf
└── 📄 Temp.pdf
